Predictors
==========

The Predictors are Python functions that take as input a image (a filename for V1 or a preprocessed image for V2) and a model and returns a post-processed image. 

The post-processing is optional for V2. Use `return_logit` option to return the raw model output.

.. automodule:: biom3d.predictors
    :members:
